@@ -27,4 +27,10 @@ class DeleteIpControlRequest(RpcRequest):
 		return self.get_query_params().get('IpControlId')
 
 	def set_IpControlId(self,IpControlId):
-		self.add_query_param('IpControlId',IpControlId)
\ No newline at end of file
+		self.add_query_param('IpControlId',IpControlId)
+
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
