@@ -35,6 +35,12 @@ class DescribeIpControlPolicyItemsRequest(RpcRequest):
 	def set_PolicyItemId(self,PolicyItemId):
 		self.add_query_param('PolicyItemId',PolicyItemId)
 
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
 
